#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-short
version:              0.1.6.1
visibility:           public
id:                   text-short-0.1.6.1-FtuI97VR1r9ExxefTpf0st
key:                  text-short-0.1.6.1-FtuI97VR1r9ExxefTpf0st
license:              BSD-3-Clause
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
synopsis:             Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.

    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' doesn'\''t support zero-copy slicing (thereby saving 2 words), and, compared to text-1.*, that it uses UTF-8 instead of UTF-16 internally. Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.

category:             Data
abi:                  f123c187dfcbc90f7a4efb581fe2a6b9
exposed:              True
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe

hidden-modules:       Data.Text.Short.Internal PrimOps
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-short-0.1.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-short-0.1.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-short-0.1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-short
hs-libraries:         HStext-short-0.1.6.1-FtuI97VR1r9ExxefTpf0st
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 deepseq-1.4.8.1
    ghc-prim-0.10.0 hashable-1.4.7.0-HpPQsoREnwfDz6Qf16RXZ0
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html:         /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

